@@ -607,13 +607,6 @@ vinagre_utils_ask_question (GtkWindow  *parent,
   return TRUE;
 }
 
-#include "vinagre-ssh.h"
-static void
-shit (void)
-{
-  vinagre_ssh_connect (NULL, NULL, -1, NULL, NULL, NULL, NULL, NULL);
-}
-
 typedef struct {
   GtkWidget *uname, *pw, *button;
 } ControlOKButton;
